==> magento-module-out-of-process-tax-management-0.10.0.zip: Api/Data/OopCustomerInterface.php <==
<?php

namespace Magento\OutOfProcessTaxManagement\Api\Data;

interface OopCustomerInterface
{

    const FIELD_ENTITY_ID = 'entity_id';
    const FIELD_WEBSITE_ID = 'website_id';
    const FIELD_GROUP_ID = 'group_id';
    const FIELD_EMAIL = 'email';
    const FIELD_FIRSTNAME = 'firstname';
    const FIELD_LASTNAME = 'lastname';

    /**
     * @return int|null
     */
    public function getEntityId(): ?int;

    /**
     * @param int $entityId
     * @return $this
     */
    public function setEntityId(int $entityId): self;

    /**
     * @return int|null
     */
    public function getWebsiteId(): ?int;

    /**
     * @param int $websiteId
     * @return self
     */
    public function setWebsiteId(int $websiteId): self;

    /**
     * @return int|null
     */
    public function getGroupId(): ?int;

    /**
     * @param int $groupId
     * @return self
     */
    public function setGroupId(int $groupId): self;

    /**
     * @return string|null
     */
    public function getEmail(): ?string;

    /**
     * @param string $email
     * @return self
     */
    public function setEmail(string $email): self;

    /**
     * @return string|null
     */
    public function getFirstname(): ?string;

    /**
     * @param string $firstname
     * @return self
     */
    public function setFirstname(string $firstname): self;

    /**
     * @return string|null
     */
    public function getLastname(): ?string;

    /**
     * @param string $lastname
     * @return self
     */
    public function setLastname(string $lastname): self;
}

==> magento-module-out-of-process-tax-management-0.10.1.zip: Api/Data/OopCustomerInterface.php <==
<?php

namespace Magento\OutOfProcessTaxManagement\Api\Data;

interface OopCustomerInterface
{

    const FIELD_ENTITY_ID = 'entity_id';
    const FIELD_WEBSITE_ID = 'website_id';
    const FIELD_GROUP_ID = 'group_id';
    const FIELD_EMAIL = 'email';
    const FIELD_FIRSTNAME = 'firstname';
    const FIELD_MIDDLENAME = 'middlename';
    const FIELD_LASTNAME = 'lastname';

    /**
     * @return int|null
     */
    public function getEntityId(): ?int;

    /**
     * @param int $entityId
     * @return $this
     */
    public function setEntityId(int $entityId): self;

    /**
     * @return int|null
     */
    public function getWebsiteId(): ?int;

    /**
     * @param int $websiteId
     * @return self
     */
    public function setWebsiteId(int $websiteId): self;

    /**
     * @return int|null
     */
    public function getGroupId(): ?int;

    /**
     * @param int $groupId
     * @return self
     */
    public function setGroupId(int $groupId): self;

    /**
     * @return string|null
     */
    public function getEmail(): ?string;

    /**
     * @param string $email
     * @return self
     */
    public function setEmail(string $email): self;

    /**
     * @return string|null
     */
    public function getFirstname(): ?string;

    /**
     * @param string $firstname
     * @return self
     */
    public function setFirstname(string $firstname): self;

    /**
     * @return string|null
     */
    public function getLastname(): ?string;

    /**
     * @param string $lastname
     * @return self
     */
    public function setLastname(string $lastname): self;

    /**
     * @return string|null
     */
    public function getMiddlename(): ?string;

    /**
     * @param string $middlename
     * @return self
     */
    public function setMiddlename(string $middlename): self;
}
